<?php

# This program is in the public domain within the United States. Additionally,
# we waive copyright and related rights in the work worldwide through the CC0
# 1.0 Universal public domain dedication, which can be found at
# http://creativecommons.org/publicdomain/zero/1.0/

# a simple, persistent, key/value store optimized for many reads and small data
#
# call persistent_{get,set,clear}

# for internal use
# IF YOU CHANGE THIS: change the version in db_upgrade() too
function persistent_init() {
	if (isset($GLOBALS['wfpl_persistent'])) {
		return;
	}
	$GLOBALS['wfpl_persistent'] = array();
	$rows = db_get_assocs('wfpl_persistent', 'k,v');
	foreach ($rows as &$row) {
		$GLOBALS['wfpl_persistent'][$row['k']] = json_decode($row['v'], true);
	} unset($row);
}

function persistent_get($k) {
	persistent_init();
	if (isset($GLOBALS['wfpl_persistent'][$k])) {
		return $GLOBALS['wfpl_persistent'][$k];
	}
	return null;
}
function persistent_set($k, $v) {
	persistent_init();
	if (isset($GLOBALS['wfpl_persistent'][$k])) {
		if ($GLOBALS['wfpl_persistent'][$k] === $v) {
			return;
		}
	}
	db_replace('wfpl_persistent', 'k,v', $k, json_encode($v));
	$GLOBALS['wfpl_persistent'][$k] = $v;
}
function persistent_clear($k) {
	persistent_init();
	if (isset($GLOBALS['wfpl_persistent'][$k])) {
		db_delete('persistent', 'where k=%"', $k);
		unset($GLOBALS['wfpl_persistent'][$k]);
	}
}

function persistent_invalidate_cache() {
	if (isset($GLOBALS['wfpl_persistent'])) {
		unset($GLOBALS['wfpl_persistent']);
	}
	return;
}

